@@ -20,6 +20,7 @@ require "signet/errors"
 require "signet/oauth_2"
 require "jwt"
 require "date"
+require "time"
 
 module Signet
   module OAuth2
@@ -110,9 +111,6 @@ module Signet
         @access_type          = nil
         update! options
       end
-      # rubocop:disable Metrics/AbcSize
-      # rubocop:disable Metrics/CyclomaticComplexity
-      # rubocop:disable Metrics/PerceivedComplexity
 
       ##
       # Updates an OAuth 2.0 client.
@@ -202,13 +200,10 @@ module Signet
         self.signing_key = options[:signing_key] if options.key? :signing_key
         self.extension_parameters = options[:extension_parameters] || {}
         self.additional_parameters = options[:additional_parameters] || {}
-        self.access_type = options.fetch(:access_type) { :offline }
+        self.access_type = options.fetch :access_type, :offline
         update_token! options
         self
       end
-      # rubocop:enable Metrics/AbcSize
-      # rubocop:enable Metrics/CyclomaticComplexity
-      # rubocop:enable Metrics/PerceivedComplexity
 
       ##
       # Updates an OAuth 2.0 client.
@@ -261,10 +256,6 @@ module Signet
 
         self
       end
-      # rubocop:disable Metrics/AbcSize
-      # rubocop:disable Metrics/CyclomaticComplexity
-      # rubocop:disable Metrics/MethodLength
-      # rubocop:disable Metrics/PerceivedComplexity
 
       ##
       # Returns the authorization URI that the user should be redirected to.
@@ -290,9 +281,7 @@ module Signet
         options[:state] = state unless options[:state]
         options.merge!(additional_parameters.merge(options[:additional_parameters] || {}))
         options.delete :additional_parameters
-        options = Hash[options.map do |key, option|
-          [key.to_s, option]
-        end]
+        options = options.transform_keys(&:to_s)
         uri = Addressable::URI.parse(
           ::Signet::OAuth2.generate_authorization_uri(
             @authorization_uri, options
@@ -304,10 +293,6 @@ module Signet
         end
         uri
       end
-      # rubocop:enable Metrics/AbcSize
-      # rubocop:enable Metrics/CyclomaticComplexity
-      # rubocop:enable Metrics/MethodLength
-      # rubocop:enable Metrics/PerceivedComplexity
 
       ##
       # Sets the authorization URI for this client.
@@ -423,7 +408,7 @@ module Signet
           end
           @scope = new_scope
         when String
-          @scope = new_scope.split " "
+          @scope = new_scope.split
         when nil
           @scope = nil
         else
@@ -793,12 +778,12 @@ module Signet
       # @param [String, Integer, nil] new_expires_in
       #   The access token lifetime.
       def expires_in= new_expires_in
-        if !new_expires_in.nil?
-          @issued_at = Time.now
-          @expires_at = @issued_at + new_expires_in.to_i
-        else
+        if new_expires_in.nil?
           @expires_at = nil
           @issued_at = nil
+        else
+          @issued_at = Time.now
+          @expires_at = @issued_at + new_expires_in.to_i
         end
       end
 
@@ -896,13 +881,13 @@ module Signet
       end
 
       def grant_type= new_grant_type
-        case new_grant_type
-        when "authorization_code", "refresh_token",
-            "password", "client_credentials"
-          @grant_type = new_grant_type
-        else
-          @grant_type = Addressable::URI.parse new_grant_type
-        end
+        @grant_type =
+          case new_grant_type
+          when "authorization_code", "refresh_token", "password", "client_credentials"
+            new_grant_type
+          else
+            Addressable::URI.parse new_grant_type
+          end
       end
 
       def to_jwt options = {}
@@ -922,8 +907,6 @@ module Signet
         assertion["sub"] = sub unless sub.nil?
         JWT.encode assertion, signing_key, signing_algorithm
       end
-      # rubocop:disable Style/MethodDefParentheses
-      # rubocop:disable Metrics/AbcSize
 
       ##
       # Serialize the client object to JSON.
@@ -931,7 +914,7 @@ module Signet
       # @note A serialized client contains sensitive information. Persist or transmit with care.
       #
       # @return [String] A serialized JSON representation of the client.
-      def to_json(*)
+      def to_json *_args
         MultiJson.dump(
           "authorization_uri"    => authorization_uri ? authorization_uri.to_s : nil,
           "token_credential_uri" => token_credential_uri ? token_credential_uri.to_s : nil,
@@ -956,10 +939,6 @@ module Signet
           "extension_parameters" => extension_parameters
         )
       end
-      # rubocop:enable Style/MethodDefParentheses
-      # rubocop:disable Metrics/CyclomaticComplexity
-      # rubocop:disable Metrics/MethodLength
-      # rubocop:disable Metrics/PerceivedComplexity
 
       ##
       # Generates a request for token credentials.
@@ -994,8 +973,8 @@ module Signet
           end
           parameters.merge! extension_parameters
         end
-        parameters["client_id"] = client_id unless client_id.nil?
-        parameters["client_secret"] = client_secret unless client_secret.nil?
+        parameters["client_id"] = client_id if !options[:use_basic_auth] && !client_id.nil?
+        parameters["client_secret"] = client_secret if !options[:use_basic_auth] && !client_secret.nil?
         if options[:scope]
           parameters["scope"] = options[:scope]
         elsif options[:use_configured_scope] && !scope.nil?
@@ -1005,8 +984,6 @@ module Signet
         additional.each { |k, v| parameters[k.to_s] = v }
         parameters
       end
-      # rubocop:enable Metrics/CyclomaticComplexity
-      # rubocop:enable Metrics/PerceivedComplexity
 
       def fetch_access_token options = {}
         raise ArgumentError, "Missing token endpoint URI." if token_credential_uri.nil?
@@ -1014,10 +991,18 @@ module Signet
         options = deep_hash_normalize options
 
         client = options[:connection] ||= Faraday.default_connection
-        url = Addressable::URI.parse(token_credential_uri).normalize.to_s
+        url = Addressable::URI.parse token_credential_uri
         parameters = generate_access_token_request options
         if client.is_a? Faraday::Connection
-          response = client.post url,
+          if options[:use_basic_auth]
+            # The Basic Auth middleware usage differs before and after Faraday v2
+            if Gem::Version.new(Faraday::VERSION).segments.first >= 2
+              client.request :authorization, :basic, client_id, client_secret
+            else
+              client.request :basic_auth, client_id, client_secret
+            end
+          end
+          response = client.post url.normalize.to_s,
                                  Addressable::URI.form_encode(parameters),
                                  "Content-Type" => "application/x-www-form-urlencoded"
           status = response.status.to_i
@@ -1025,7 +1010,11 @@ module Signet
           content_type = response.headers["Content-type"]
         else
           # Hurley
-          response = client.post url, parameters
+          if options[:use_basic_auth]
+            url.user = client_id
+            url.password = client_secret
+          end
+          response = client.post url.normalize.to_s, parameters
           status = response.status_code.to_i
           body = response.body
           content_type = response.header[:content_type]
@@ -1035,20 +1024,16 @@ module Signet
 
         message = "  Server message:\n#{response.body.to_s.strip}" unless body.to_s.strip.empty?
         if [400, 401, 403].include? status
-          message = "Authorization failed." + message
-          raise ::Signet::AuthorizationError.new(
-            message, response: response
-          )
+          message = "Authorization failed.#{message}"
+          raise ::Signet::AuthorizationError.new message, response: response
         elsif status.to_s[0] == "5"
-          message = "Remote server error." + message
+          message = "Remote server error.#{message}"
           raise ::Signet::RemoteServerError, message
         else
-          message = "Unexpected status code: #{response.status}." + message
+          message = "Unexpected status code: #{response.status}.#{message}"
           raise ::Signet::UnexpectedStatusError, message
         end
       end
-      # rubocop:enable Metrics/AbcSize
-      # rubocop:enable Metrics/MethodLength
 
       def fetch_access_token! options = {}
         token_hash = fetch_access_token options
@@ -1068,9 +1053,6 @@ module Signet
       def refresh! options = {}
         fetch_access_token! options
       end
-      # rubocop:disable Metrics/AbcSize
-      # rubocop:disable Metrics/MethodLength
-      # rubocop:disable Metrics/PerceivedComplexity
 
       ##
       # Generates an authenticated request for protected resources.
@@ -1137,9 +1119,6 @@ module Signet
         request["Cache-Control"] = "no-store"
         request
       end
-      # rubocop:enable Metrics/AbcSize
-      # rubocop:enable Metrics/MethodLength
-      # rubocop:enable Metrics/PerceivedComplexity
 
       ##
       # Transmits a request for a protected resource.
